#
# spec file for package python-jsonpath-ng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jsonpath-ng
Version:        1.7.0
Release:        1.4
Summary:        JSONPath for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/h2non/jsonpath-ng
Source:         https://github.com/h2non/jsonpath-ng/archive/refs/tags/v%{version}.tar.gz#/jsonpath-ng-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-decorator
Requires:       python-ply
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ply}
#
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A final implementation of JSONPath for Python that aims to be
standard compliant, including arithmetic and binary comparison
operators and providing clear AST for metaprogramming.

%prep
%setup -q -n jsonpath-ng-%{version}
sed -i '1{/^#!/d}' jsonpath_ng/bin/jsonpath.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jsonpath_ng
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative jsonpath_ng

%postun
%python_uninstall_alternative jsonpath_ng

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst History.md
%python_alternative %{_bindir}/jsonpath_ng
%{python_sitelib}/jsonpath_ng
%{python_sitelib}/jsonpath_ng-%{version}.dist-info

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Allow raw numeric values to be used as keys
  * Add `wherenot`
  * Added EZRegex pattern for the split extension regex
  * Added negative and * indecies and quotes to `Split`
    parameters
  * Typo: duplicate line removed.
  * Added `path` extension that exposes datum's path from the
    jsonpath expression itself.
  * Remove Python 3.7 support
  * Only construct the parse table once
  * updated test for `jsonpath.py` changes
  * fix for Updating a json object fails if the value of a key is
    boolean #73
  * Add Codespaces configuration
  * Add `.editorconfig`
  * Fix a GitHub workflow schema issue
* Fri Feb  9 2024 Christian Keil <keil@dfn-cert.de>
- Switch to Python 3.11 build.
- Remove build dependency oslotest (pull request #137).
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.6.1:
  * Fix issue with lambda based updates
  * Remove unused code from the test suite
  * De-duplicate the parser test cases
  * Remove a test that merely checks exception inheritance
  * Add pytest-randomly to shake out auto_id side effects
  * Include the test suite in coverage reports
  * Remove tests that don't affect coverage and contribute
    nothing
  * Reformat `tests/test_create.py`
  * Remove `test_doctests`, which is a no-op
  * Demonstrate that there are no doctests
  * Remove the `coveralls` dependency
  * Migrate `tests/bin/test_jsonpath.py` to use pytest
  * remove Python2 crumbs
  * Add CodeQL analysis
  * Remove the `oslotest` dependency
  * Fix running CI against incoming PRs
  * Support, and test against, Python 3.12
  * Update the currently-tested CPython versions in the README
  * Remove an unused Travis CI config file
  * Add a Dependabot config to keep GitHub action versions
    updated
  * add a test for the case when root element is a list
  * Fix issue with assignment in case root element is a list.
  * Fix typo in README
  * Fix test commands in Makefile
  * Fix .coveragerc path
  * Simplify clean in Makefile
  * Refactor unit tests for better errors
  * test case for existing auto id
  * Add more examples to README (thanks @baynes)
  * Don't fail when regex match is attempted on non-strings
  * Add additional tests
  * Add `keys` keyword
* Fri Sep 15 2023 pgajdos@suse.com
- version update to 1.6.0
  1.6.0 / 2023-09-13
  * Enclose field names containing literals in quotes
  * Add note about extensions
  * Remove documentation status link
  * Update supported versions in setup.py
  * Add LICENSE file
  * Code cleanup
  * Remove dependency on six
  * Update build status badge
  * (origin/github-actions, github-actions) Remove testscenarios dependency
  * Remove pytest version constraints
  * Add testing with GitHub actions
  * Escape back slashes in tests to avoid DeprecationWarning.
  * Use raw strings for regular expressions to avoid DeprecationWarning.
  * refactor(package): remove dependency for decorator
  * Merge pull request #128 from michaelmior/hashable
  * (origin/hashable, hashable) Make path instances hashable
  * Merge pull request #122 from snopoke/snopoke-patch-1
  * Add more detail to filter docs.
  * remove incorrect parenthesis in filter examples
  * Merge pull request #119 from snopoke/patch-1
  * add 'sub' line with function param names
  * readme formatting fixes
  * chore(history): update
  * Update __init__.py
  1.5.3 / 2021-07-05
  * Update __init__.py
  * Update setup.py
  * Merge pull request #72 from kaapstorm/find_or_create
  * Tests
  * Add `update_or_create()` method
  * Merge pull request #68 from kaapstorm/example_tests
  * Merge pull request #70 from kaapstorm/exceptions
  * Add/fix `__eq__()`
  * Add tests based on Stefan Goessner's examples
  * Tests
  * Allow callers to catch JSONPathErrors
- six and decorator are not required
* Wed Nov  3 2021 pgajdos@suse.com
- version update to 1.5.2
  * Merge pull request #41 from josephwhite13/allow-dictionary-filtering
  * Merge pull request #48 from back2root/master
  * Check for null value.
  * Merge pull request #40 from memborsky/add-regular-expression-contains-support
  * feat: support regular expression for performing contains (=~) filtering
  * if datum.value is a dictionary, filter on the list of values
- %%check: use python -m pytest instead of setup.py test
* Thu Apr 29 2021 John Vandenberg <jayvdb@gmail.com>
- Tidy spec
- Activate test suite
* Sun Apr 25 2021 Martin Hauke <mardnh@gmx.de>
- Package cleanup
* Sat May 23 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.5.1
